@@ -22,6 +22,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "buffer_interface.h"
 #include "clientconnection.h"
 #include "compositor_interface.h"
+#include "idleinhibit_interface_p.h"
 #include "pointerconstraints_interface_p.h"
 #include "region_interface.h"
 #include "subcompositor_interface.h"
@@ -213,6 +214,22 @@ void SurfaceInterface::Private::installPointerConstraint(LockedPointerInterface
     emit q_func()->pointerConstraintsChanged();
 }
 
+void SurfaceInterface::Private::installIdleInhibitor(IdleInhibitorInterface *inhibitor)
+{
+    idleInhibitors << inhibitor;
+    QObject::connect(inhibitor, &IdleInhibitorInterface::aboutToBeUnbound, q,
+        [this, inhibitor] {
+            idleInhibitors.removeOne(inhibitor);
+            if (idleInhibitors.isEmpty()) {
+                emit q_func()->inhibitsIdleChanged();
+            }
+        }
+    );
+    if (idleInhibitors.count() == 1) {
+        emit q_func()->inhibitsIdleChanged();
+    }
+}
+
 void SurfaceInterface::Private::installPointerConstraint(ConfinedPointerInterface *confinement)
 {
     Q_ASSERT(lockedPointer.isNull());
@@ -256,7 +273,7 @@ const struct wl_surface_interface SurfaceInterface::Private::s_interface = {
     resourceDestroyedCallback,
     attachCallback,
     damageCallback,
-    frameCallaback,
+    frameCallback,
     opaqueRegionCallback,
     inputRegionCallback,
     commitCallback,
@@ -588,7 +605,7 @@ void SurfaceInterface::Private::damageCallback(wl_client *client, wl_resource *r
     cast<Private>(resource)->damage(QRect(x, y, width, height));
 }
 
-void SurfaceInterface::Private::frameCallaback(wl_client *client, wl_resource *resource, uint32_t callback)
+void SurfaceInterface::Private::frameCallback(wl_client *client, wl_resource *resource, uint32_t callback)
 {
     auto s = cast<Private>(resource);
     Q_ASSERT(client == *s->client);
@@ -856,6 +873,12 @@ QPointer<ConfinedPointerInterface> SurfaceInterface::confinedPointer() const
     return d->confinedPointer;
 }
 
+bool SurfaceInterface::inhibitsIdle() const
+{
+    Q_D();
+    return !d->idleInhibitors.isEmpty();
+}
+
 SurfaceInterface::Private *SurfaceInterface::d_func() const
 {
     return reinterpret_cast<Private*>(d.data());
